function out = subsref(obj,s)
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% out=subsref(Pbop,s) used for subscripted indexing of the operator P: R^p x L2^q to R^m x L2^n

% 
% INPUT
% obj: dopvar class object to slice
% s: structure of indices used for reference (auto generated by matlab
% based on subscript expression
% 
% OUTPUT
% out: dopvar object (if slicing the operator), otherwise depends on the
% subscript expression
%  
% NOTES:
% For support, contact M. Peet, Arizona State University at mpeet@asu.edu
% or S. Shivakumar at sshivak8@asu.edu

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% PIETools - ctranspose
%
% Copyright (C)2019  M. Peet, S. Shivakumar
%
% This program is free software; you can redistribute it and/or modify
% it under the terms of the GNU General Public License as published by
% the Free Software Foundation; either version 2 of the License, or
% (at your option) any later version.
%
% This program is distributed in the hope that it will be useful,
% but WITHOUT ANY WARRANTY; without even the implied warranty of
% MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
% GNU General Public License for more details.
%
% You should have received a copy of the GNU General Public License
% along with this program; if not, write to the Free Software
% Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%
% If you modify this code, document all changes carefully and include date
% authorship, and a brief description of modifications
%
% Initial coding MMP, SS  - 6_14_2022
%

switch s(1).type
    case '.'
        out = builtin('subsref',obj,s);
    case '()'
        indr = s(1).subs{1};
        indc = s(1).subs{2};
        dim_old=obj.dim;
        Pold=obj.P;
        Q1old=obj.Q1;
        Q2old=obj.Q2;
        R0old=obj.R.R0;
        R1old=obj.R.R1;
        R2old=obj.R.R2;

        nr1_old=dim_old(1,1);
        nr2_old=dim_old(2,1);
        nc1_old=dim_old(1,2);
        nc2_old=dim_old(2,2);
        nr1_new=0;
        nr2_new=0;
        nc1_new=0;
        nc2_new=0;
        indr1=[];
        indr2=[];
        indc1=[];
        indc2=[];

        for i=indr %rows
            if i<(nr1_old+1)
                nr1_new=nr1_new+1;
                indr1=[indr1 i];
            elseif i<(nr1_old+nr2_old+1)
                nr2_new=nr2_new+1;
                indr2=[indr2 i-nr1_old];
            else
                error('index exceeds the number of rows in the original opvar')
            end
        end
        for i=indc %columns
            if i<(nc1_old+1)
                nc1_new=nc1_new+1;
                indc1=[indc1 i];
            elseif i<(nc1_old+nc2_old+1)
                nc2_new=nc2_new+1;
                indc2=[indc2 i-nc1_old];
            else
                error('index exceeds the number of columns in the original opvar')
            end
        end
        % Construct the sliced opvar
        opvar Psop;
        Psop.I=obj.I;
        Psop.var1=obj.var1;
        Psop.var2=obj.var2;
        Psop.dim=[nr1_new nc1_new;
            nr2_new nc2_new];
        Psop.P=Pold(indr1,indc1);
        Psop.Q1=Q1old(indr1,indc2);
        Psop.Q2=Q2old(indr2,indc1);
        Psop.R.R0=R0old(indr2,indc2);
        Psop.R.R1=R1old(indr2,indc2);
        Psop.R.R2=R2old(indr2,indc2);
        
        if length(s)>=2
            out = builtin('subsref',Psop,s(2:end));
        else
            out = Psop;
        end
    case '{}'
        error('Not a valid indexing expression')
end
end